==> xl-react-components-0.18.103.tgz: package/tests/e2e/dsl/component/dip/dip-list.js <==
import {Action, Expectation} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';

export const clickAddButton = () =>
    Action.click('.testComponent .xl-react-components-input .xl-btn-add');

export const expectAddButtonDisabled = () =>
    Expectation.disabled('.testComponent .xl-react-components-input .xl-btn-add');

export const expectAddButtonEnabled = () =>
    Expectation.enabled('.testComponent .xl-react-components-input .xl-btn-add');

export const expectAddButtonNotPresent = () =>
    Expectation.notPresent('.testComponent .xl-react-components-input .xl-btn-add');

export const expectClearSelectionPresent = () =>
    Expectation.displayed('.testComponent .dip-input .xl-react-btn-close');

export const expectClearSelectionNotPresent = () =>
    Expectation.notPresent('.testComponent .dip-input .xl-react-btn-close');

export const expectInputNotPresent = () =>
    Expectation.notPresent('.testComponent .dip-input input');

export const expectReadonlyInput = () =>
    Expectation.hasAttribute('.testComponent .dip-input input', 'readonly');

export const expectNotReadonlyInput = () =>
    Expectation.hasNoAttribute('.testComponent .dip-input input', 'readonly');

export const expectSelectedItemToEqual = (itemNumber, value) => {
    const selector = `.testComponent .xl-scrollable-panel .xl-list-row:nth-child(${itemNumber}) .text-container`;
    return Expectation.textEquals(selector, value);
};

export const removeClearSelectedItemPresent = (itemNumber) => {
    const rowSelector = `.testComponent .xl-scrollable-panel .xl-list-row:nth-child(${itemNumber})`;
    return Expectation.present(`${rowSelector} .xl-react-btn-close`);
};

export const removeClearSelectedItemNotPresent = (itemNumber) => {
    const rowSelector = `.testComponent .xl-scrollable-panel .xl-list-row:nth-child(${itemNumber})`;
    return Expectation.notPresent(`${rowSelector} .xl-react-btn-close`);
};

export const removeSelectedItem = (itemNumber) => {
    const rowSelector = `.testComponent .xl-scrollable-panel .xl-list-row:nth-child(${itemNumber})`;
    return Action.click(`${rowSelector} .xl-react-btn-close`);
};

export const setValue = (value) =>
    Action.typeText('.testComponent .dip-input input', value);

const DipList = {
    ...XlComponent,
    clickAddButton,
    expectAddButtonDisabled,
    expectAddButtonEnabled,
    expectAddButtonNotPresent,
    expectReadonlyInput,
    expectClearSelectionNotPresent,
    expectClearSelectionPresent,
    expectInputNotPresent,
    expectNotReadonlyInput,
    expectSelectedItemToEqual,
    removeClearSelectedItemPresent,
    removeClearSelectedItemNotPresent,
    removeSelectedItem,
    setValue
};

export default DipList;
global.DipList = DipList;

==> xl-react-components-0.21.12.tgz: package/tests/e2e/dsl/component/dip/dip-list.js <==
import {Action, Expectation} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';

export const clickAddButton = () =>
    Action.click('.testComponent .xl-react-components-input .xl-btn-add');

export const expectAddButtonDisabled = () =>
    Expectation.disabled('.testComponent .xl-react-components-input .xl-btn-add');

export const expectAddButtonEnabled = () =>
    Expectation.enabled('.testComponent .xl-react-components-input .xl-btn-add');

export const expectAddButtonNotPresent = () =>
    Expectation.notPresent('.testComponent .xl-react-components-input .xl-btn-add');

export const expectClearSelectionPresent = () =>
    Expectation.displayed('.testComponent .dip-input .close-icon');

export const expectClearSelectionNotPresent = () =>
    Expectation.notPresent('.testComponent .dip-input .close-icon');

export const expectInputNotPresent = () =>
    Expectation.notPresent('.testComponent .dip-input input');

export const expectReadonlyInput = () =>
    Expectation.hasAttribute('.testComponent .dip-input input', 'readonly');

export const expectNotReadonlyInput = () =>
    Expectation.hasNoAttribute('.testComponent .dip-input input', 'readonly');

export const expectSelectedItemToEqual = (itemNumber, value) => {
    const selector = `.testComponent .xl-scrollable-panel .xl-list-row:nth-child(${itemNumber}) .text-container`;
    return Expectation.textEquals(selector, value);
};

export const removeClearSelectedItemPresent = (itemNumber) => {
    const rowSelector = `.testComponent .xl-scrollable-panel .xl-list-row:nth-child(${itemNumber})`;
    return Expectation.present(`${rowSelector} .close-icon`);
};

export const removeClearSelectedItemNotPresent = (itemNumber) => {
    const rowSelector = `.testComponent .xl-scrollable-panel .xl-list-row:nth-child(${itemNumber})`;
    return Expectation.notPresent(`${rowSelector} .close-icon`);
};

export const removeSelectedItem = (itemNumber) => {
    const rowSelector = `.testComponent .xl-scrollable-panel .xl-list-row:nth-child(${itemNumber})`;
    return Action.click(`${rowSelector} .close-icon`);
};

export const setValue = (value) =>
    Action.typeText('.testComponent .dip-input input', value);

const DipList = {
    ...XlComponent,
    clickAddButton,
    expectAddButtonDisabled,
    expectAddButtonEnabled,
    expectAddButtonNotPresent,
    expectReadonlyInput,
    expectClearSelectionNotPresent,
    expectClearSelectionPresent,
    expectInputNotPresent,
    expectNotReadonlyInput,
    expectSelectedItemToEqual,
    removeClearSelectedItemPresent,
    removeClearSelectedItemNotPresent,
    removeSelectedItem,
    setValue
};

export default DipList;
global.DipList = DipList;
